# Table of Contents

- [portfolio-report](<./portfolio-report.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Portfolio Report](<./Portfolio-Report.md>)
  - [How is it useful?](<./Portfolio-Report/How-is-it-useful.md>)
  - [Using the Portfolio Reports](<./Portfolio-Report/Using-the-Portfolio-Reports.md>)
  - [Editing in the Report](<./Portfolio-Report/Editing-in-the-Report.md>)
  - [Applying Filter](<./Portfolio-Report/Applying-Filter.md>)
